@@ -1,5 +1,5 @@
 package Selenium::Remote::Commands;
-$Selenium::Remote::Commands::VERSION = '0.2150'; # TRIAL
+$Selenium::Remote::Commands::VERSION = '0.2151'; # TRIAL
 # ABSTRACT: Implement commands for Selenium::Remote::Driver
 
 use Moo;
@@ -279,11 +279,6 @@ has '_cmds' => (
                 'url'                => 'session/:sessionId/window',
                 'no_content_success' => 1
             },
-            'dragElement' => {
-                'method'             => 'POST',
-                'url'                => 'session/:sessionId/element/:id/drag',
-                'no_content_success' => 1
-            },
             'getElementSize' => {
                 'method'             => 'GET',
                 'url'                => 'session/:sessionId/element/:id/size',
@@ -426,7 +421,7 @@ Selenium::Remote::Commands - Implement commands for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 0.2150
+version 0.2151
 
 =head1 SEE ALSO
 
